@@ -77,7 +77,7 @@ void Process_free(T *P);
 /**
  * Returns the user id of the sub-process
  * @param P A Process object
- * @return The user id the sub-process
+ * @return The user id of the sub-process
  */
 uid_t Process_getUid(T P);
 
@@ -85,21 +85,11 @@ uid_t Process_getUid(T P);
 /**
  * Returns the group id of the sub-process
  * @param P A Process object
- * @return The group id the sub-process
+ * @return The group id of the sub-process
  */
 gid_t Process_getGid(T P);
 
 
-/**
- * Returns the Process timeout. 
- * @param P A Process object
- * @return The number of seconds this Process has until exit before
- * the <code>onTimeout</code> handler is called if it is defined for
- * the Command. 0 means that there is no timeout.
- */
-int Process_getTimeout(T P);
-
-
 /**
  * Returns the working directory of the Process
  * @param P A Process object
