@@ -70,13 +70,11 @@ void System_error(const char *e, ...) __attribute__((format (printf, 1, 2)));
 
 /**
  * Returns the number of available file descriptors for a process.
- * This method uses <code>getdtablesize</code> internally, but returns
- * a fixed size of <code>max</code> if <code>getdtablesize</code> returns
- * a value outside the range [3..max].
- * @param max Upper limit for descriptors
+ * This method uses <code>sysconf</code> internally, but returns
+ * a fixed size of <code>2^16</code> if the value is larger. 
  * @return A guarded number of available file descriptors for a process
  */
-int System_getDescriptorsGuarded(int max);
+int System_getDescriptorsGuarded(void);
 
 
 #endif
