@@ -1,6 +1,7 @@
-#!/bin/bash
+#!/bin/sh
 
-export PATH=$PATH:.
+PATH="$PATH:."
+export PATH
 
 StrTest && \
 TimeTest && \
