@@ -143,7 +143,7 @@ static int _commandExecute(Service_T S, command_t c, char *msg, int msglen, int6
                                 *timeout -= RETRY_INTERVAL;
                         } while ((status = Process_exitStatus(P)) < 0 && *timeout > 0 && ! (Run.flags & Run_Stopped));
                         if (*timeout <= 0)
-                                snprintf(msg, msglen, "Program '%s' timed out after %s", Util_commandDescription(c, (char[STRLEN]){}), Str_milliToTime(_timeoutMilli, (char[23]){}));
+                                snprintf(msg, msglen, "Program '%s' timed out after %s", Util_commandDescription(c, (char[STRLEN]){}), Str_time2str(_timeoutMilli, (char[10]){}));
                         int n, total = 0;
                         char buf[STRLEN];
                         do {
