@@ -37,23 +37,13 @@
 /**
  * Initialize the programs file variables
  */
-void file_init();
+void file_init(void);
 
 
 /**
  * Finalize and remove temporary files
  */
-void file_finalize();
-
-
-/**
- * Get a object's last modified timestamp.
- * @param object A object to stat
- * @param type Requested object's type
- * @return Max of either st_mtime or st_ctime or
- * 0 if not found or different type of object
- */
-time_t file_getTimestamp(char *object, mode_t type);
+void file_finalize(void);
 
 
 /**
@@ -63,7 +53,7 @@ time_t file_getTimestamp(char *object, mode_t type);
  * not found.
  * @return The location of monits control file (monitrc)
  */
-char *file_findControlFile();
+char *file_findControlFile(void);
 
 
 /**
