@@ -77,6 +77,7 @@ static void _gc_mmonit(Mmonit_T *);
 static void _gc_url(URL_T *);
 static void _gc_request(Request_T *);
 static void _gcssloptions(SslOptions_T o);
+static void _gcsecattr(SecurityAttribute_T *);
 
 
 /**
@@ -186,7 +187,8 @@ static void _gc_service(Service_T *s) {
                         Command_free(&(*s)->program->C);
                 if ((*s)->program->args)
                         gccmd(&(*s)->program->args);
-                StringBuffer_free(&((*s)->program->output));
+                StringBuffer_free(&((*s)->program->lastOutput));
+                StringBuffer_free(&((*s)->program->inprogressOutput));
                 FREE((*s)->program);
         }
         if ((*s)->portlist)
@@ -269,6 +271,8 @@ static void _gc_service(Service_T *s) {
                 _gc_eventaction(&(*s)->action_ACTION);
         if ((*s)->eventlist)
                 gc_event(&(*s)->eventlist);
+        if ((*s)->secattrlist)
+                _gcsecattr(&(*s)->secattrlist);
         switch ((*s)->type) {
                 case Service_Directory:
                         FREE((*s)->inf.directory);
@@ -664,3 +668,14 @@ static void _gc_mmonit(Mmonit_T *recv) {
         FREE(*recv);
 }
 
+
+static void _gcsecattr(SecurityAttribute_T *s) {
+        ASSERT(s && *s);
+        if ((*s)->next)
+                _gcsecattr(&(*s)->next);
+        if ((*s)->action)
+                _gc_eventaction(&(*s)->action);
+        FREE((*s)->attribute);
+        FREE(*s);
+}
+
