@@ -179,12 +179,7 @@ static boolean_t _client(const char *request, StringBuffer_T data) {
         }
         Socket_T S = NULL;
         if (Run.httpd.flags & Httpd_Net) {
-                SslOptions_T options = {
-                        .flags = (Run.httpd.flags & Httpd_Ssl) ? SSL_Enabled : SSL_Disabled,
-                        .clientpemfile = Run.httpd.socket.net.ssl.clientpem,
-                        .allowSelfSigned = Run.httpd.flags & Httpd_AllowSelfSignedCertificates
-                };
-                S = Socket_create(Run.httpd.socket.net.address ? Run.httpd.socket.net.address : "localhost", Run.httpd.socket.net.port, Socket_Tcp, Socket_Ip, options, Run.limits.networkTimeout);
+                S = Socket_create(Run.httpd.socket.net.address ? Run.httpd.socket.net.address : "localhost", Run.httpd.socket.net.port, Socket_Tcp, Socket_Ip, &(Run.httpd.socket.net.ssl), Run.limits.networkTimeout);
         } else if (Run.httpd.flags & Httpd_Unix) {
                 S = Socket_createUnix(Run.httpd.socket.unix.path, Socket_Tcp, Run.limits.networkTimeout);
         } else {
