@@ -60,6 +60,10 @@
 #include <unistd.h>
 #endif
 
+#ifdef HAVE_COREFOUNDATION_COREFOUNDATION_H
+#include <CoreFoundation/CoreFoundation.h>
+#endif
+
 #include "monit.h"
 #include "event.h"
 #include "ProcessTree.h"
@@ -95,6 +99,7 @@ static void _delete(ProcessTree_T **pt, int *size) {
                 for (int i = 0; i < *size; i++) {
                         FREE(_pt[i].cmdline);
                         FREE(_pt[i].children.list);
+                        FREE(_pt[i].secattr);
                 }
                 FREE(_pt);
                 *pt = NULL;
@@ -127,17 +132,25 @@ static int _findProcess(int pid, ProcessTree_T *pt, int size) {
  */
 static void _fillProcessTree(ProcessTree_T *pt, int index) {
         if (! pt[index].visited) {
-                pt[index].visited            = true;
-                pt[index].children.total     = pt[index].children.count;
+                pt[index].visited = true;
+                pt[index].children.total = pt[index].children.count;
+                pt[index].threads.children = 0;
+                pt[index].cpu.usage.children = 0.;
                 pt[index].memory.usage_total = pt[index].memory.usage;
-                pt[index].cpu.usage_total    = pt[index].cpu.usage;
-                for (int i = 0; i < pt[index].children.count; i++)
+                for (int i = 0; i < pt[index].children.count; i++) {
                         _fillProcessTree(pt, pt[index].children.list[i]);
+                }
                 if (pt[index].parent != -1 && pt[index].parent != index) {
-                        ProcessTree_T *parent_pt       = &pt[pt[index].parent];
-                        parent_pt->children.total     += pt[index].children.total;
-                        parent_pt->memory.usage_total += pt[index].memory.usage_total;
-                        parent_pt->cpu.usage_total    += pt[index].cpu.usage_total;
+                        ProcessTree_T *parent_pt = &pt[pt[index].parent];
+                        parent_pt->children.total += pt[index].children.total;
+                        parent_pt->threads.children += (pt[index].threads.self > 1 ? pt[index].threads.self : 1) + (pt[index].threads.children > 0 ? pt[index].threads.children : 0);
+                        if (pt[index].cpu.usage.self >= 0) {
+                                parent_pt->cpu.usage.children += pt[index].cpu.usage.self;
+                        }
+                        if (pt[index].cpu.usage.children >= 0) {
+                                parent_pt->cpu.usage.children += pt[index].cpu.usage.children;
+                        }
+                        parent_pt->memory.usage_total  += pt[index].memory.usage_total;
                 }
         }
 }
@@ -151,22 +164,22 @@ static void _fillProcessTree(ProcessTree_T *pt, int index) {
  * @param delta The delta of system time between current and previous cycle
  * @return Process' CPU usage [%] since last cycle
  */
-static float _cpuUsage(ProcessTree_T *now, ProcessTree_T *prev, double delta) {
-        if (systeminfo.cpus > 0 && delta > 0 && prev->cpu.time > 0 && now->cpu.time > prev->cpu.time) {
+static float _cpuUsage(float rawUsage, unsigned threads) {
+        if (systeminfo.cpu.count > 0 && rawUsage > 0) {
                 int divisor;
-                if (now->threads > 1) {
-                        if (now->threads >= systeminfo.cpus) {
+                if (threads > 1) {
+                        if (threads >= systeminfo.cpu.count) {
                                 // Multithreaded application with more threads then CPU cores
-                                divisor = systeminfo.cpus;
+                                divisor = systeminfo.cpu.count;
                         } else {
                                 // Multithreaded application with less threads then CPU cores
-                                divisor = now->threads;
+                                divisor = threads;
                         }
                 } else {
                         // Single threaded application
                         divisor = 1;
                 }
-                float usage = (100. * (now->cpu.time - prev->cpu.time) / delta) / divisor;
+                float usage = rawUsage / divisor;
                 return usage > 100. ? 100. : usage;
         }
         return 0.;
@@ -200,6 +213,7 @@ int ProcessTree_init(ProcessEngine_Flags pflags) {
                 for (int i = 0; i < oldptreesize; i++) {
                         FREE(oldptree[i].cmdline);
                         FREE(oldptree[i].children.list);
+                        FREE(oldptree[i].secattr);
                 }
         }
 
@@ -220,10 +234,14 @@ int ProcessTree_init(ProcessEngine_Flags pflags) {
         ProcessTree_T *pt = ptree;
         double time_delta = systeminfo.time - systeminfo.time_prev;
         for (int i = 0; i < (volatile int)ptreesize; i ++) {
+                pt[i].cpu.usage.self = -1;
                 if (oldptree) {
                         int oldentry = _findProcess(pt[i].pid, oldptree, oldptreesize);
-                        if (oldentry != -1)
-                                pt[i].cpu.usage = _cpuUsage(&pt[i], &oldptree[oldentry], time_delta);
+                        if (oldentry != -1) {
+                                if (systeminfo.cpu.count > 0 && time_delta > 0 && oldptree[oldentry].cpu.time >= 0 && pt[i].cpu.time >= oldptree[oldentry].cpu.time) {
+                                        pt[i].cpu.usage.self = 100. * (pt[i].cpu.time - oldptree[oldentry].cpu.time) / time_delta;
+                                }
+                        }
                 }
                 // Note: on DragonFly, main process is swapper with pid 0 and ppid -1, so take also this case into consideration
                 if ((pt[i].pid == pt[i].ppid) || (pt[i].ppid == -1)) {
@@ -271,29 +289,47 @@ boolean_t ProcessTree_updateProcess(Service_T s, pid_t pid) {
         ASSERT(s);
 
         /* save the previous pid and set actual one */
-        s->inf->priv.process._pid = s->inf->priv.process.pid;
-        s->inf->priv.process.pid  = pid;
+        s->inf.process->_pid = s->inf.process->pid;
+        s->inf.process->pid  = pid;
 
         int leaf = _findProcess(pid, ptree, ptreesize);
         if (leaf != -1) {
                 /* save the previous ppid and set actual one */
-                s->inf->priv.process._ppid             = s->inf->priv.process.ppid;
-                s->inf->priv.process.ppid              = ptree[leaf].ppid;
-                s->inf->priv.process.uid               = ptree[leaf].cred.uid;
-                s->inf->priv.process.euid              = ptree[leaf].cred.euid;
-                s->inf->priv.process.gid               = ptree[leaf].cred.gid;
-                s->inf->priv.process.uptime            = ptree[leaf].uptime;
-                s->inf->priv.process.threads           = ptree[leaf].threads;
-                s->inf->priv.process.children          = ptree[leaf].children.total;
-                s->inf->priv.process.zombie            = ptree[leaf].zombie;
-                s->inf->priv.process.cpu_percent       = ptree[leaf].cpu.usage;
-                s->inf->priv.process.total_cpu_percent = ptree[leaf].cpu.usage_total > 100. ? 100. : ptree[leaf].cpu.usage_total;
-                s->inf->priv.process.mem               = ptree[leaf].memory.usage;
-                s->inf->priv.process.total_mem         = ptree[leaf].memory.usage_total;
-                if (systeminfo.mem_max > 0) {
-                        s->inf->priv.process.total_mem_percent = ptree[leaf].memory.usage_total >= systeminfo.mem_max ? 100. : (100. * (double)ptree[leaf].memory.usage_total / (double)systeminfo.mem_max);
-                        s->inf->priv.process.mem_percent       = ptree[leaf].memory.usage >= systeminfo.mem_max ? 100. : (100. * (double)ptree[leaf].memory.usage / (double)systeminfo.mem_max);
+                s->inf.process->_ppid             = s->inf.process->ppid;
+                s->inf.process->ppid              = ptree[leaf].ppid;
+                s->inf.process->uid               = ptree[leaf].cred.uid;
+                s->inf.process->euid              = ptree[leaf].cred.euid;
+                s->inf.process->gid               = ptree[leaf].cred.gid;
+                s->inf.process->uptime            = ptree[leaf].uptime;
+                s->inf.process->threads           = ptree[leaf].threads.self;
+                s->inf.process->children          = ptree[leaf].children.total;
+                s->inf.process->zombie            = ptree[leaf].zombie;
+                snprintf(s->inf.process->secattr, STRLEN, "%s", ptree[leaf].secattr);
+                if (ptree[leaf].cpu.usage.self >= 0) {
+                        // compute only if initialized (delta between current and previous snapshot is available)
+                        s->inf.process->cpu_percent = _cpuUsage(ptree[leaf].cpu.usage.self, ptree[leaf].threads.self);
+                        s->inf.process->total_cpu_percent = s->inf.process->cpu_percent + _cpuUsage(ptree[leaf].cpu.usage.children, ptree[leaf].threads.children);
+                        if (s->inf.process->total_cpu_percent > 100.) {
+                                s->inf.process->total_cpu_percent = 100.;
+                        }
+                } else {
+                        s->inf.process->cpu_percent = -1;
+                        s->inf.process->total_cpu_percent = -1;
                 }
+                s->inf.process->mem               = ptree[leaf].memory.usage;
+                s->inf.process->total_mem         = ptree[leaf].memory.usage_total;
+                if (systeminfo.memory.size > 0) {
+                        s->inf.process->total_mem_percent = ptree[leaf].memory.usage_total >= systeminfo.memory.size ? 100. : (100. * (double)ptree[leaf].memory.usage_total / (double)systeminfo.memory.size);
+                        s->inf.process->mem_percent       = ptree[leaf].memory.usage >= systeminfo.memory.size ? 100. : (100. * (double)ptree[leaf].memory.usage / (double)systeminfo.memory.size);
+                }
+                if (ptree[leaf].read.bytes)
+                        Statistics_update(&(s->inf.process->read.bytes), ptree[leaf].read.time, ptree[leaf].read.bytes);
+                if (ptree[leaf].read.operations)
+                        Statistics_update(&(s->inf.process->read.operations), ptree[leaf].read.time, ptree[leaf].read.operations);
+                if (ptree[leaf].write.bytes)
+                        Statistics_update(&(s->inf.process->write.bytes), ptree[leaf].write.time, ptree[leaf].write.bytes);
+                if (ptree[leaf].write.operations)
+                        Statistics_update(&(s->inf.process->write.operations), ptree[leaf].write.time, ptree[leaf].write.operations);
                 return true;
         }
         Util_resetInfo(s);
@@ -313,10 +349,10 @@ time_t ProcessTree_getProcessUptime(pid_t pid) {
 pid_t ProcessTree_findProcess(Service_T s) {
         ASSERT(s);
         // Test the cached PID first
-        if (s->inf->priv.process.pid > 0) {
+        if (s->inf.process->pid > 0) {
                 errno = 0;
-                if (getpgid(s->inf->priv.process.pid) > -1 || errno == EPERM)
-                        return s->inf->priv.process.pid;
+                if (getpgid(s->inf.process->pid) > -1 || errno == EPERM)
+                        return s->inf.process->pid;
         }
         // If the cached PID is not running, scan for the process again
         if (s->matchlist) {
@@ -329,7 +365,7 @@ pid_t ProcessTree_findProcess(Service_T s) {
                 } else {
                         DEBUG("Process information not available -- skipping service %s process existence check for this cycle\n", s->name);
                         // Return value is NOOP - it is based on existing errors bitmap so we don't generate false recovery/failures
-                        return ! (s->error & Event_Nonexist);
+                        return ! (s->error & Event_NonExist);
                 }
         } else {
                 pid_t pid = Util_getPid(s->path);
@@ -413,9 +449,34 @@ boolean_t init_system_info(void) {
                 LogError("'%s' resource monitoring initialization error -- uname failed: %s\n", Run.system->name, STRERROR);
                 return false;
         }
-        systeminfo.total_cpu_user_percent = -1.;
-        systeminfo.total_cpu_syst_percent = -1.;
-        systeminfo.total_cpu_wait_percent = -1.;
+#ifdef HAVE_COREFOUNDATION_COREFOUNDATION_H
+        CFURLRef url = CFURLCreateWithFileSystemPath(NULL, CFSTR("/System/Library/CoreServices/SystemVersion.plist"), kCFURLPOSIXPathStyle, false);
+        if (url) {
+                CFReadStreamRef stream = CFReadStreamCreateWithFile(NULL, url);
+                if (stream) {
+                        if (CFReadStreamOpen(stream)) {
+                                CFPropertyListRef propertyList = CFPropertyListCreateWithStream(NULL, stream, 0, kCFPropertyListImmutable, NULL, NULL);
+                                if (propertyList) {
+                                        CFStringRef value = CFDictionaryGetValue(propertyList, CFSTR("ProductName"));
+                                        if (value) {
+                                                CFStringGetCString(value, systeminfo.uname.sysname, sizeof(systeminfo.uname.sysname), CFStringGetSystemEncoding());
+                                        }
+                                        value = CFDictionaryGetValue(propertyList, CFSTR("ProductVersion"));
+                                        if (value) {
+                                                CFStringGetCString(value, systeminfo.uname.release, sizeof(systeminfo.uname.release), CFStringGetSystemEncoding());
+                                        }
+                                        CFRelease(propertyList);
+                                }
+                                CFReadStreamClose(stream);
+                        }
+                        CFRelease(stream);
+                }
+                CFRelease(url);
+        }
+#endif
+        systeminfo.cpu.usage.user = -1.;
+        systeminfo.cpu.usage.system = -1.;
+        systeminfo.cpu.usage.wait = -1.;
         return (init_process_info_sysdep());
 }
 
@@ -432,8 +493,8 @@ boolean_t update_system_info() {
                         LogError("'%s' statistic error -- memory usage data collection failed\n", Run.system->name);
                         goto error2;
                 }
-                systeminfo.total_mem_percent  = systeminfo.mem_max > 0ULL ? (100. * (double)systeminfo.total_mem / (double)systeminfo.mem_max) : 0.;
-                systeminfo.total_swap_percent = systeminfo.swap_max > 0ULL ? (100. * (double)systeminfo.total_swap / (double)systeminfo.swap_max) : 0.;
+                systeminfo.memory.usage.percent  = systeminfo.memory.size > 0ULL ? (100. * (double)systeminfo.memory.usage.bytes / (double)systeminfo.memory.size) : 0.;
+                systeminfo.swap.usage.percent = systeminfo.swap.size > 0ULL ? (100. * (double)systeminfo.swap.usage.bytes / (double)systeminfo.swap.size) : 0.;
 
                 if (! used_system_cpu_sysdep(&systeminfo)) {
                         LogError("'%s' statistic error -- cpu usage data collection failed\n", Run.system->name);
@@ -448,14 +509,14 @@ error1:
         systeminfo.loadavg[1] = 0;
         systeminfo.loadavg[2] = 0;
 error2:
-        systeminfo.total_mem = 0ULL;
-        systeminfo.total_mem_percent = 0.;
-        systeminfo.total_swap = 0ULL;
-        systeminfo.total_swap_percent = 0.;
+        systeminfo.memory.usage.bytes = 0ULL;
+        systeminfo.memory.usage.percent = 0.;
+        systeminfo.swap.usage.bytes = 0ULL;
+        systeminfo.swap.usage.percent = 0.;
 error3:
-        systeminfo.total_cpu_user_percent = 0.;
-        systeminfo.total_cpu_syst_percent = 0.;
-        systeminfo.total_cpu_wait_percent = 0.;
+        systeminfo.cpu.usage.user = 0.;
+        systeminfo.cpu.usage.system = 0.;
+        systeminfo.cpu.usage.wait = 0.;
 
         return false;
 }
